@@ -1,6 +1,6 @@
 /*
     sredird: RFC 2217 compliant serial port redirector
-    Version 2.2.0, 09 July 2003
+    Version 2.2.1, 20 February 2004
     Copyright (C) 1999 - 2003 InfoTecna s.r.l.
     Copyright (C) 2001, 2002 Trustees of Columbia University
     in the City of New York
@@ -117,8 +117,8 @@
 #include <netinet/tcp.h>
 
 /* Version id */
-#define VersionId "2.2.0"
-#define SRedirdVersionId "Version " VersionId ", 09 July 2003"
+#define VersionId "2.2.1"
+#define SRedirdVersionId "Version " VersionId ", 20 February 2004"
 
 /* Locking constants */
 #define LockOk 0
@@ -439,7 +439,11 @@ void AddToBuffer(BufferType * B, unsigned char C)
 
 void PushToBuffer(BufferType * B, unsigned char C)
   {
-    B->RdPos = (B->RdPos == 0 ? BufferSize - 1 : B->RdPos--);
+    if (B->RdPos > 0) 
+      B->RdPos--; 
+    else 
+      B->RdPos = BufferSize - 1; 
+	   
     B->Buffer[B->RdPos] = C;
   }
 
